## django-iranian-cities was originally created in May 2021
#### Here is an inevitably incomplete list of MUCH-APPRECIATED CONTRIBUTORS 

| Name                          | Role                     | Status                     | Email                      |
| ----------------------------- |:------------------------:|:--------------------------:|:--------------------------:|
| Sepehr Akbarzadeh             | Team Lead                |  In-Progress               |  sepehr@gmail.com          |
| Mehran Rahmanzadeh            | Developer                |  In-Progress               |  mrhnz13@gmail.com         |

A big THANK-YOU goes to:

    SageTeam for letting us open-source django-iranian-cities.

    Guido van Rossum for creating Python.

    Django Software Foundation for creating Django.